Package 'tbd'
| Title: |
Estimation of causal effects with outcomes truncated by death |
| Description: |
Estimation of the survivor average causal effect under
outcomes truncated by death, which requires the existence of a
substitution variable. It can be applied to both experimental
and observational data. |
| Authors: |
Zhixuan Shao [cre], Bo Liu [ctb], Linbo Wang [aut] |
| Maintainer: |
Zhixuan Shao <[email protected]> |
| License: |
GPL-3 |
| Version: |
0.0.0.9000 |
| Built: |
2026-05-16 08:44:11 UTC |
| Source: |
https://github.com/killingvectorfield/causal-inference-truncated-by-death |
Help Index